@@ -24,10 +24,27 @@ class WordPressManager {
      * Execute WP-CLI command in a container
      */
     private function execWpCli($container, $user, $command, $workDir = null) {
+        // Validate input parameters to prevent command injection
+        if (!preg_match('/^[a-zA-Z0-9_-]+$/', $user)) {
+            throw new Exception("Invalid user format: $user");
+        }
+        if (!preg_match('/^[a-zA-Z0-9.-]+-[0-9]+$/', $container)) {
+            throw new Exception("Invalid container format: $container");
+        }
+        if (strlen($user) > 32 || strlen($container) > 64) {
+            throw new Exception("User or container name too long");
+        }
+        
         if ($workDir === null) {
             $workDir = "/home/{$user}/public_html";
         }
         
+        // Validate work directory path
+        $workDir = realpath($workDir) ?: $workDir;
+        if (!str_starts_with($workDir, '/home/') && !str_starts_with($workDir, '/docker/users/')) {
+            throw new Exception("Invalid work directory: $workDir");
+        }
+        
         // Build the docker exec command
         $dockerCmd = sprintf(
             "docker exec --user %s -w %s %s %s",
@@ -326,6 +343,144 @@ class WordPressManager {
         }
     }
     
+    /**
+     * Update WordPress core, plugins, and themes
+     * @param int $siteId Site ID
+     * @return array Result array
+     */
+    public function updateAll($siteId) {
+        $site = $this->getSite($siteId);
+        if (!$site) {
+            throw new Exception("Site not found");
+        }
+        
+        // Record update start for comprehensive update
+        $updateId = $this->recordUpdateStart($siteId, 'all', 'WordPress Complete Update', $site['wp_version']);
+        
+        try {
+            // Perform the comprehensive update
+            $result = $this->performCompleteUpdateBackground($siteId, $updateId);
+            
+            return [
+                'success' => true, 
+                'message' => 'WordPress complete update finished successfully',
+                'update_id' => $updateId,
+                'status' => 'completed',
+                'results' => $result
+            ];
+            
+        } catch (Exception $e) {
+            // Record failure
+            $this->recordUpdateFailed($updateId, $e->getMessage());
+            
+            return [
+                'success' => false,
+                'message' => 'WordPress complete update failed: ' . $e->getMessage(),
+                'update_id' => $updateId,
+                'status' => 'failed'
+            ];
+        }
+    }
+    
+    /**
+     * Perform comprehensive WordPress update (core, plugins, themes) in background
+     */
+    public function performCompleteUpdateBackground($siteId, $updateId) {
+        $site = $this->getSite($siteId);
+        if (!$site) {
+            throw new Exception("Site not found");
+        }
+        
+        $container = $site['domain_name'] . '-01';
+        $user = $site['username'];
+        $results = [
+            'core' => null,
+            'plugins' => null,
+            'themes' => null,
+            'backup_results' => null
+        ];
+        
+        // Update status to in_progress
+        $this->recordUpdateProgress($updateId, 'Creating backup before complete update...');
+        
+        // Create backup first
+        if ($site['backup_target_id']) {
+            try {
+                $backupResult = $this->createBackup($siteId);
+                $results['backup_results'] = $backupResult;
+                $this->recordUpdateProgress($updateId, 'Backup created successfully');
+            } catch (Exception $e) {
+                $this->recordUpdateProgress($updateId, 'Backup failed: ' . $e->getMessage());
+                // Continue with update even if backup fails
+            }
+        }
+        
+        // Update WordPress core
+        $this->recordUpdateProgress($updateId, 'Updating WordPress core...');
+        try {
+            $coreResult = $this->execWpCli($container, $user, "wp core update");
+            if ($coreResult['success']) {
+                $results['core'] = ['success' => true, 'message' => 'Core updated successfully'];
+                $this->recordUpdateProgress($updateId, 'WordPress core updated successfully');
+            } else {
+                $results['core'] = ['success' => false, 'message' => $coreResult['error']];
+                $this->recordUpdateProgress($updateId, 'Core update failed: ' . $coreResult['error']);
+            }
+        } catch (Exception $e) {
+            $results['core'] = ['success' => false, 'message' => $e->getMessage()];
+            $this->recordUpdateProgress($updateId, 'Core update exception: ' . $e->getMessage());
+        }
+        
+        // Update all plugins
+        $this->recordUpdateProgress($updateId, 'Updating plugins...');
+        try {
+            $pluginResult = $this->execWpCli($container, $user, "wp plugin update --all");
+            if ($pluginResult['success']) {
+                $results['plugins'] = ['success' => true, 'message' => 'Plugins updated successfully'];
+                $this->recordUpdateProgress($updateId, 'All plugins updated successfully');
+            } else {
+                $results['plugins'] = ['success' => false, 'message' => $pluginResult['error']];
+                $this->recordUpdateProgress($updateId, 'Plugin updates failed: ' . $pluginResult['error']);
+            }
+        } catch (Exception $e) {
+            $results['plugins'] = ['success' => false, 'message' => $e->getMessage()];
+            $this->recordUpdateProgress($updateId, 'Plugin update exception: ' . $e->getMessage());
+        }
+        
+        // Update all themes
+        $this->recordUpdateProgress($updateId, 'Updating themes...');
+        try {
+            $themeResult = $this->execWpCli($container, $user, "wp theme update --all");
+            if ($themeResult['success']) {
+                $results['themes'] = ['success' => true, 'message' => 'Themes updated successfully'];
+                $this->recordUpdateProgress($updateId, 'All themes updated successfully');
+            } else {
+                $results['themes'] = ['success' => false, 'message' => $themeResult['error']];
+                $this->recordUpdateProgress($updateId, 'Theme updates failed: ' . $themeResult['error']);
+            }
+        } catch (Exception $e) {
+            $results['themes'] = ['success' => false, 'message' => $e->getMessage()];
+            $this->recordUpdateProgress($updateId, 'Theme update exception: ' . $e->getMessage());
+        }
+        
+        // Get new WordPress version
+        $versionResult = $this->execWpCli($container, $user, "wp core version");
+        $newVersion = $versionResult['success'] ? trim($versionResult['output']) : null;
+        
+        // Update site version in database if core update was successful and we got a new version
+        if ($results['core']['success'] && $newVersion) {
+            $stmt = $this->db->prepare("UPDATE sites SET wp_version = ? WHERE id = ?");
+            $stmt->execute([$newVersion, $siteId]);
+            $results['new_version'] = $newVersion;
+        }
+        
+        // Record completion
+        $this->recordUpdateComplete($updateId, $newVersion);
+        $this->recordUpdateProgress($updateId, 'Complete update finished');
+        
+        return $results;
+    }
+    
     /**
      * Perform WordPress core update in background
      */
@@ -1419,10 +1574,15 @@ Options -Indexes
             throw new Exception("Permission denied: You can only manage your own WordPress sites");
         }
         
-        // Update the database
-        $columnName = "auto_update_" . $updateType;
+        // Update the database with safe column mapping to prevent SQL injection
+        $validColumns = [
+            'core' => 'auto_update_core',
+            'plugins' => 'auto_update_plugins', 
+            'themes' => 'auto_update_themes'
+        ];
+        $columnName = $validColumns[$updateType];
         $enabledValue = $enabled ? 1 : 0; // Ensure it's explicitly 1 or 0
-        $stmt = $this->db->prepare("UPDATE wordpress_sites SET {$columnName} = ? WHERE id = ?");
+        $stmt = $this->db->prepare("UPDATE wordpress_sites SET `{$columnName}` = ? WHERE id = ?");
         $stmt->execute([$enabledValue, $siteId]);
         
         if ($stmt->rowCount() === 0) {
